

	
			QT_TRANSLATE_NOOP("@default", "Look");
		
		
			QT_TRANSLATE_NOOP("@default", "Chat");
		
			
			QT_TRANSLATE_NOOP("@default", "Headers and separators");
		
				
			QT_TRANSLATE_NOOP("@default", "Chat header separators height");
		
				
			QT_TRANSLATE_NOOP("@default", "Message separators height");
		
				
			QT_TRANSLATE_NOOP("@default", "Remove chat header repetitions");
		
				
			QT_TRANSLATE_NOOP("@default", "Interval between header removal");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Server time");
		
				
			QT_TRANSLATE_NOOP("@default", "Remove server time");
		
				
			QT_TRANSLATE_NOOP("@default", "Maximum time difference");
		
			






			
			QT_TRANSLATE_NOOP("@default", "Window title");
		
				
			QT_TRANSLATE_NOOP("@default", "Chat window title syntax");
		
				
			QT_TRANSLATE_NOOP("@default", "Conference window title prefix");
		
				
			QT_TRANSLATE_NOOP("@default", "Conference window title syntax");
		
			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Kadu");
		
		
			QT_TRANSLATE_NOOP("@default", "Kadu");
		
			
			QT_TRANSLATE_NOOP("@default", "Language");
		
				
			QT_TRANSLATE_NOOP("@default", "Language");
		
			QT_TRANSLATE_NOOP("@default", "Choose your language");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Updates");
		
				
			QT_TRANSLATE_NOOP("@default", "Check for updates");
		
			QT_TRANSLATE_NOOP("@default", "Automatically checks whether a new version is available");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Startup");
		
				
			QT_TRANSLATE_NOOP("@default", "Start on startup");
		
			QT_TRANSLATE_NOOP("@default", "Automatically start on system startup");
		
			

		

		
			QT_TRANSLATE_NOOP("@default", "Applications");
		
			
			QT_TRANSLATE_NOOP("@default", "WWW browser");
		
				
			QT_TRANSLATE_NOOP("@default", "Choose your browser");
		
			QT_TRANSLATE_NOOP("@default", "Choose your browser");
		
					
			QT_TRANSLATE_NOOP("@default", "Specify path");
		
					
			QT_TRANSLATE_NOOP("@default", "Konqueror");
		
					
			QT_TRANSLATE_NOOP("@default", "Opera");
		
					
			QT_TRANSLATE_NOOP("@default", "Opera (new tab)");
		
					
			QT_TRANSLATE_NOOP("@default", "Mozilla");
		
					
			QT_TRANSLATE_NOOP("@default", "SeaMonkey");
		
					
			QT_TRANSLATE_NOOP("@default", "Mozilla Firefox");
		
					
			QT_TRANSLATE_NOOP("@default", "Dillo");
		
					
			QT_TRANSLATE_NOOP("@default", "Galeon");
		
					
			QT_TRANSLATE_NOOP("@default", "Safari");
		
				
				
			QT_TRANSLATE_NOOP("@default", "Custom browser");
		
			QT_TRANSLATE_NOOP("@default", "Write specific path to your browser");
		
			

			
			QT_TRANSLATE_NOOP("@default", "e-mail client");
		
				
			QT_TRANSLATE_NOOP("@default", "Choose your e-mail client");
		
			QT_TRANSLATE_NOOP("@default", "Choose your email client");
		
					
			QT_TRANSLATE_NOOP("@default", "Specify path");
		
					
			QT_TRANSLATE_NOOP("@default", "KMail");
		
					
			QT_TRANSLATE_NOOP("@default", "Thunderbird");
		
					
			QT_TRANSLATE_NOOP("@default", "SeaMonkey");
		
					
			QT_TRANSLATE_NOOP("@default", "Evolution");
		
                
				
			QT_TRANSLATE_NOOP("@default", "Custom e-mail client");
		
			QT_TRANSLATE_NOOP("@default", "Write specific path to your email client");
		
			
		
		
		
			QT_TRANSLATE_NOOP("@default", "Advanced");
		
			
			QT_TRANSLATE_NOOP("@default", "Parser");
		
				
			QT_TRANSLATE_NOOP("@default", "Allow executing commands by parser");
		
			
			
			QT_TRANSLATE_NOOP("@default", "Debugging");
		
				
			QT_TRANSLATE_NOOP("@default", "Debugging mask");
		
			
		
			
	

	
			QT_TRANSLATE_NOOP("@default", "Account");
		
		
			QT_TRANSLATE_NOOP("@default", "Gadu-Gadu");
		
			
			QT_TRANSLATE_NOOP("@default", "User data");
		
				
			QT_TRANSLATE_NOOP("@default", "UIN");
		
				
			QT_TRANSLATE_NOOP("@default", "Password");
		
				
			QT_TRANSLATE_NOOP("@default", "Nick");
		
			
		

		
			QT_TRANSLATE_NOOP("@default", "Server");
		
			
			QT_TRANSLATE_NOOP("@default", "Servers properties");
		
				
			QT_TRANSLATE_NOOP("@default", "Use default servers");
		
				
			QT_TRANSLATE_NOOP("@default", "IP Addresses");
		
			QT_TRANSLATE_NOOP("@default", "You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)");
		
				
			QT_TRANSLATE_NOOP("@default", "Port to connect to servers");
		
					
			QT_TRANSLATE_NOOP("@default", "Automatic");
		
					
			QT_TRANSLATE_NOOP("@default", "8074");
		
					
			QT_TRANSLATE_NOOP("@default", "443");
		
				
			

			
			QT_TRANSLATE_NOOP("@default", "Proxy Server");
		
				
			QT_TRANSLATE_NOOP("@default", "Use proxy server");
		
				
			QT_TRANSLATE_NOOP("@default", "Host");
		
				
			QT_TRANSLATE_NOOP("@default", "Port");
		
				
			QT_TRANSLATE_NOOP("@default", "Username");
		
				
			QT_TRANSLATE_NOOP("@default", "Password");
		
			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Contacts");
		
		
			QT_TRANSLATE_NOOP("@default", "General");
		
			
			QT_TRANSLATE_NOOP("@default", "Filters");
		
				
			QT_TRANSLATE_NOOP("@default", "Show offline contacts");
		
				
			QT_TRANSLATE_NOOP("@default", "Show contacts that are blocked");
		
				
			QT_TRANSLATE_NOOP("@default", "Show contacts which are blocking me");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Anonymous");
		
				
			QT_TRANSLATE_NOOP("@default", "Ignore messages from anonymous users");
		
				
			QT_TRANSLATE_NOOP("@default", "Ignore messages from anonymous users also in conferences");
		
				
			QT_TRANSLATE_NOOP("@default", "Ignore richtext from anonymous users");
		
			QT_TRANSLATE_NOOP("@default", "Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.");
		

			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Status");
		
		
			QT_TRANSLATE_NOOP("@default", "General");
		
			
			QT_TRANSLATE_NOOP("@default", "General");
		
				
			QT_TRANSLATE_NOOP("@default", "Private status");
		
			QT_TRANSLATE_NOOP("@default", "When enabled, you're visible only to users on your list");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Descirption");
		
				
			QT_TRANSLATE_NOOP("@default", "On startup, set");
		
			QT_TRANSLATE_NOOP("@default", "Choose status which will be set on startup");
		
					
			QT_TRANSLATE_NOOP("@default", "Last status");
		
					
			QT_TRANSLATE_NOOP("@default", "Online");
		
					
			QT_TRANSLATE_NOOP("@default", "Busy");
		
					
			QT_TRANSLATE_NOOP("@default", "Invisible");
		
					
			QT_TRANSLATE_NOOP("@default", "Offline");
		
				
				
			QT_TRANSLATE_NOOP("@default", "Set invisible if last status was 'Offline'");
		
				
			QT_TRANSLATE_NOOP("@default", "On startup, set last description");
		
			QT_TRANSLATE_NOOP("@default", "Last decription will be set on startup");
		
				
			QT_TRANSLATE_NOOP("@default", "On startup, set description");
		
			QT_TRANSLATE_NOOP("@default", "Define description which will be set on startup");
		
				
			QT_TRANSLATE_NOOP("@default", "On shutdown, keep current description");
		
			QT_TRANSLATE_NOOP("@default", "Current description will be set on shutdown");
		
				
			QT_TRANSLATE_NOOP("@default", "On shutdown, set description");
		
			QT_TRANSLATE_NOOP("@default", "Define description which will be set on shutdown");
		
				
			QT_TRANSLATE_NOOP("@default", "Number of kept descriptions");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Advanced");
		
				
			QT_TRANSLATE_NOOP("@default", "Allow using variables in status");
		
			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Look");
		
		
			QT_TRANSLATE_NOOP("@default", "General");
		
			
			QT_TRANSLATE_NOOP("@default", "General");
		
				
			QT_TRANSLATE_NOOP("@default", "Theme");
		
			QT_TRANSLATE_NOOP("@default", "Choose Qt style");
		
				
			QT_TRANSLATE_NOOP("@default", "Icon theme");
		
			QT_TRANSLATE_NOOP("@default", "Choose icon theme");
		
				
			QT_TRANSLATE_NOOP("@default", "Icon paths");
		
			QT_TRANSLATE_NOOP("@default", "Definie icons paths");
		
				
			QT_TRANSLATE_NOOP("@default", "Show status changing button");
		
			
		

		
			QT_TRANSLATE_NOOP("@default", "Colors");
		
			
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "Text edit");
		
				
			QT_TRANSLATE_NOOP("@default", "My messages");
		
				
			QT_TRANSLATE_NOOP("@default", "User messages");
		
				
			QT_TRANSLATE_NOOP("@default", "My font");
		
				
			QT_TRANSLATE_NOOP("@default", "User font");
		
				
			QT_TRANSLATE_NOOP("@default", "My nick");
		
				
			QT_TRANSLATE_NOOP("@default", "User nick");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Background");
		
				
			QT_TRANSLATE_NOOP("@default", "Font");
		
				
			QT_TRANSLATE_NOOP("@default", "Descriptions font");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Information Panel");
		
				
			QT_TRANSLATE_NOOP("@default", "Background");
		
				
			QT_TRANSLATE_NOOP("@default", "Font");
		
			

		

		
			QT_TRANSLATE_NOOP("@default", "Fonts");
		
			
			QT_TRANSLATE_NOOP("@default", "Fonts");
		
				
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "Userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Font in panel");
		
			
        

		
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
			
			QT_TRANSLATE_NOOP("@default", "New messages notifications");
		
				
			QT_TRANSLATE_NOOP("@default", "Activate windows with new messages");
		
				
			QT_TRANSLATE_NOOP("@default", "Flash chat title on new message");
		
				
			QT_TRANSLATE_NOOP("@default", "Show number of new messages on chat title");
		
				
			QT_TRANSLATE_NOOP("@default", "Nice date format");
		
			QT_TRANSLATE_NOOP("@default", "Display dates is nice format, like Today, Yesterday or Friday");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Style");
		
				
			QT_TRANSLATE_NOOP("@default", "Style");
		
			QT_TRANSLATE_NOOP("@default", "Choose style of chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "Preview");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Emoticons");
		
				
			QT_TRANSLATE_NOOP("@default", "Emoticons");
		
			QT_TRANSLATE_NOOP("@default", "Choose emoticons style");
		
					
			QT_TRANSLATE_NOOP("@default", "Animated");
		
					
			QT_TRANSLATE_NOOP("@default", "Static");
		
					
			QT_TRANSLATE_NOOP("@default", "None");
		
				
				
			QT_TRANSLATE_NOOP("@default", "Emoticons theme");
		
			QT_TRANSLATE_NOOP("@default", "Choose emoticons theme");
		
				
			QT_TRANSLATE_NOOP("@default", "Emoticons paths");
		
			QT_TRANSLATE_NOOP("@default", "Define emoticons paths");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Advanced");
		
				
			QT_TRANSLATE_NOOP("@default", "Advanced...");
		
			
		

		
			QT_TRANSLATE_NOOP("@default", "Userbox");
		
			
			QT_TRANSLATE_NOOP("@default", "General");
		
				
			QT_TRANSLATE_NOOP("@default", "Display group tabs");
		
			QT_TRANSLATE_NOOP("@default", "Displays group tabs on userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Show available contacts in bold");
		
			QT_TRANSLATE_NOOP("@default", "Displays users that are not offline using a bold font");
		
				
			QT_TRANSLATE_NOOP("@default", "Align contact icon to");
		
			QT_TRANSLATE_NOOP("@default", "Align icon next to contact name");
		
					
			QT_TRANSLATE_NOOP("@default", "Top");
		
					
			QT_TRANSLATE_NOOP("@default", "Center");
		
				
				
			QT_TRANSLATE_NOOP("@default", "Column count");
		
			QT_TRANSLATE_NOOP("@default", "Number of columns displays in userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Tool tip style");
		
			QT_TRANSLATE_NOOP("@default", "Choose userbox tool-tip style");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Descriptions");
		
				
			QT_TRANSLATE_NOOP("@default", "Show descriptions");
		
			QT_TRANSLATE_NOOP("@default", "Displays descriptions in userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Allow multiline descriptions");
		
			QT_TRANSLATE_NOOP("@default", "Dislpays multiline descriptions in userbox");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Background");
		
				
			QT_TRANSLATE_NOOP("@default", "Use background image");
		
				
			QT_TRANSLATE_NOOP("@default", "Background file");
		
			QT_TRANSLATE_NOOP("@default", "Define background file for userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Display style");
		
			QT_TRANSLATE_NOOP("@default", "Choose userbox background style");
		
					
			QT_TRANSLATE_NOOP("@default", "Tiled");
		
					
			QT_TRANSLATE_NOOP("@default", "Centered");
		
					
			QT_TRANSLATE_NOOP("@default", "Stretched");
		
				
			
		

		
			QT_TRANSLATE_NOOP("@default", "Information Panel");
		
			
			QT_TRANSLATE_NOOP("@default", "General");
		
				
			QT_TRANSLATE_NOOP("@default", "Show information panel");
		
			QT_TRANSLATE_NOOP("@default", "Displays information panel below userbox");
		
				
			QT_TRANSLATE_NOOP("@default", "Show vertical scrollbar");
		
			QT_TRANSLATE_NOOP("@default", "Show vertical scrollbar in information panel");
		
				
			QT_TRANSLATE_NOOP("@default", "Show emoticons in panel");
		
			QT_TRANSLATE_NOOP("@default", "Show emoticons in information panel");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Style");
		
				
			QT_TRANSLATE_NOOP("@default", "Style");
		
			QT_TRANSLATE_NOOP("@default", "Choose information panel style");
		
				
			QT_TRANSLATE_NOOP("@default", "Preview");
		
			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Shortcuts");
		
		
			QT_TRANSLATE_NOOP("@default", "General");
		
			
			QT_TRANSLATE_NOOP("@default", "Kadu");
		
				
			QT_TRANSLATE_NOOP("@default", "Configuration");
		
				
			QT_TRANSLATE_NOOP("@default", "Add user");
		
				
			QT_TRANSLATE_NOOP("@default", "Manage modules");
		
				
			QT_TRANSLATE_NOOP("@default", "Open chat with...");
		
			
		
		
			QT_TRANSLATE_NOOP("@default", "Userlist");
		
			
			QT_TRANSLATE_NOOP("@default", "Userlist");
		
				
			QT_TRANSLATE_NOOP("@default", "Remove from userlist");
		
				
			QT_TRANSLATE_NOOP("@default", "Properties");
		
				
			QT_TRANSLATE_NOOP("@default", "Search this user in directory");
		
				
			QT_TRANSLATE_NOOP("@default", "Show / hide offline users");
		
				
			QT_TRANSLATE_NOOP("@default", "Show / hide users without description");
		
			
		
		
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
			
			QT_TRANSLATE_NOOP("@default", "Chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "New line / send message");
		
				
			QT_TRANSLATE_NOOP("@default", "Clear chat");
		
				
			QT_TRANSLATE_NOOP("@default", "Close chat");
		
				
			QT_TRANSLATE_NOOP("@default", "Bold text");
		
				
			QT_TRANSLATE_NOOP("@default", "Italic text");
		
				
			QT_TRANSLATE_NOOP("@default", "Underline text");
		
			
		
	

	
			QT_TRANSLATE_NOOP("@default", "Chat");
		
		
			QT_TRANSLATE_NOOP("@default", "General");
		
			
			QT_TRANSLATE_NOOP("@default", "Behaviour");
		
				
			QT_TRANSLATE_NOOP("@default", "Remember chat windows positions");
		
				
			QT_TRANSLATE_NOOP("@default", "Open chat window on new message");
		
			QT_TRANSLATE_NOOP("@default", "Open chat window when comes new message");
		
				
			QT_TRANSLATE_NOOP("@default", "Open chat window only when I'm online");
		
			QT_TRANSLATE_NOOP("@default", "Open chat window on new message only when online");
		
				
			QT_TRANSLATE_NOOP("@default", "Wait for message delivery");
		
			QT_TRANSLATE_NOOP("@default", "Wait for confirmation from server during send messages");
		
				
			QT_TRANSLATE_NOOP("@default", "'Enter' in chat send message");
		
			QT_TRANSLATE_NOOP("@default", "'Enter' in chat send message");
		
				
			QT_TRANSLATE_NOOP("@default", "Confirm clearing chat window");
		
			QT_TRANSLATE_NOOP("@default", "Ask before clearing chat window");
		
				
			QT_TRANSLATE_NOOP("@default", "Save opened windows on exit");
		
			QT_TRANSLATE_NOOP("@default", "Save opened chat windows when exiting");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Closing");
		
				
			QT_TRANSLATE_NOOP("@default", "Block window close on new message");
		
			QT_TRANSLATE_NOOP("@default", "Block chat window when comes new message");
		
				
			QT_TRANSLATE_NOOP("@default", "Max time to block window close");
		
			QT_TRANSLATE_NOOP("@default", "Max time to block window close");
		
			
		
		
			QT_TRANSLATE_NOOP("@default", "Messages");
		
			
			QT_TRANSLATE_NOOP("@default", "Message pruning");
		
				
			QT_TRANSLATE_NOOP("@default", "Automatically prune chat messages");
		
			QT_TRANSLATE_NOOP("@default", "If enabled, messages are pruning");
		
				
			QT_TRANSLATE_NOOP("@default", "Reduce the number of visible messages in chat window to");
		
			QT_TRANSLATE_NOOP("@default", "Number of visible messages");
		
			
			
			
			QT_TRANSLATE_NOOP("@default", "Images");
		
				
			QT_TRANSLATE_NOOP("@default", "Max image size");
		
			QT_TRANSLATE_NOOP("@default", "Maximum image size that we want to receive");
		
				
			QT_TRANSLATE_NOOP("@default", "Receive images during invisibility");
		
			QT_TRANSLATE_NOOP("@default", "Receiving images during invisibility is allowed");
		
				
			QT_TRANSLATE_NOOP("@default", "Limit numbers of image recevied per minute");
		
			QT_TRANSLATE_NOOP("@default", "Define limit of images received per minute");
		
			

			
			QT_TRANSLATE_NOOP("@default", "Link folding");
		
				
			QT_TRANSLATE_NOOP("@default", "Automatically fold links");
		
				
			QT_TRANSLATE_NOOP("@default", "Fold links longer than");
		
			
		
	

